@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
-$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.109';
+$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.110';
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla;
@@ -155,7 +155,7 @@ for my $attr (@run_attributes) {
   );
 }
 
-my @alien_options = qw( repo name bins pattern_prefix pattern_suffix pattern_version pattern autoconf_with_pic isolate_dynamic );
+my @alien_options = qw( msys repo name bins pattern_prefix pattern_suffix pattern_version pattern autoconf_with_pic isolate_dynamic );
 
 my @alien_attributes = map { 'alien_'.$_ } @alien_options;
 
@@ -168,6 +168,13 @@ for my $attr (@alien_attributes) {
   );
 }
 
+has alien_bin_requires => (
+  is      => 'ro',
+  isa     => 'ArrayRef[Str]',
+  lazy    => 1,
+  default => sub { defined $_[0]->payload->{alien_bin_requires} ? $_[0]->payload->{alien_bin_requires} : [] },
+);
+
 my @travis_str_options = (
   @Dist::Zilla::Plugin::TravisCI::bools,
 );
@@ -201,7 +208,7 @@ for my $attr (@travis_array_attributes) {
   );
 }
 
-sub mvp_multivalue_args { @travis_array_attributes, @run_attributes }
+sub mvp_multivalue_args { @travis_array_attributes, @run_attributes, 'alien_bin_requires' }
 
 sub configure {
   my ($self) = @_;
@@ -298,6 +305,9 @@ sub configure {
       my $func = 'alien_'.$_;
       $alien_values{$_} = $self->$func if defined $self->$func && $self->$func ne '';
     }
+    if(@{ $self->alien_bin_requires }) {
+      $alien_values{bin_requires} = $self->alien_bin_requires;
+    }
     $self->add_plugins([
       'Alien' => \%alien_values,
     ]);
@@ -345,7 +355,7 @@ sub configure {
       $self->add_plugins([
         'ChangelogFromGit' => {
           max_age => 99999,
-          tag_regexp => '^v(.+)$',
+          tag_regexp => '^v?(\d.+)$',
           file_name => 'Changes',
           wrap_column => 74,
           debug => 0,
@@ -384,7 +394,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.109
+version 0.110
 
 =head1 SYNOPSIS
 
